==> nfdump_1.7.4.orig.tar.gz: nfdump-1.7.4/src/test/runzstd.sh <==
#!/bin/sh
#  This file is part of the nfdump project.
#
#  Copyright (c) 2023, Peter Haag
#  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions and the following disclaimer in the documentation
#     and/or other materials provided with the distribution.
#   * Neither the name of Peter Haag nor the names of its contributors may be
#     used to endorse or promote products derived from this software without
#     specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
#  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
#  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
#  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
#  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
#  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
#  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
#  POSSIBILITY OF SUCH DAMAGE.
#

set -e
TZ=MET
export TZ

# prevent any default goelookup for testing
NFDUMP="../nfdump/nfdump -G none"

# zstd compression tests
$NFDUMP -J 4 -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J 1 -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J zstd -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J zstd:5 -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J zstd:9 -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J 0 -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null
$NFDUMP -J lzo -r test.flows.nf && $NFDUMP -v test.flows.nf >/dev/null

==> nfdump_1.7.6.orig.tar.gz: nfdump-1.7.6/src/test/runzstd.sh <==
#!/bin/sh
#  This file is part of the nfdump project.
#
#  Copyright (c) 2023-2024, Peter Haag
#  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions and the following disclaimer in the documentation
#     and/or other materials provided with the distribution.
#   * Neither the name of Peter Haag nor the names of its contributors may be
#     used to endorse or promote products derived from this software without
#     specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
#  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
#  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
#  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
#  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
#  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
#  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
#  POSSIBILITY OF SUCH DAMAGE.
#

set -e
TZ=MET
export TZ

# prevent any default goelookup for testing
NFDUMP="../nfdump/nfdump -G none"

# zstd compression tests
$NFDUMP -J 4 -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J 1 -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J zstd -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J zstd:5 -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J zstd:9 -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J 0 -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
$NFDUMP -J lzo -r dummy_flows.nf && $NFDUMP -v dummy_flows.nf >/dev/null
